libgd: Dynamic graphics generation tool
=======================================

Description
-----------

GD is an open source code library for the dynamic creation of images by
programmers. GD is written in C, and "wrappers" are available for Perl,
PHP and other languages. GD creates PNG, JPEG, GIF, WebP, XPM, BMP
images, among other formats. GD is commonly used to generate charts,
graphics, thumbnails, and most anything else, on the fly. While not
restricted to use on the web, the most common applications of GD involve
website development.

License
-------

-  Custom (BSD-ish)


Upstream Contact
----------------

-  https://libgd.github.io
-  Pierre Joye (http://blog.thepimp.net)
-  https://github.com/libgd/libgd
